@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: apr 30 2018 (23:45) 
 ## Version: 
-## Last-Updated: sep 24 2018 (11:00) 
+## Last-Updated: okt 16 2018 (21:41) 
 ##           By: Brice Ozenne
-##     Update #: 78
+##     Update #: 93
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -22,9 +22,6 @@ if(FALSE){
 
 context("Check that method.tte = corrected  in BuyseTest is working correctly \n")
 
-
-
-
 ## * settings
 BuyseTest.options(check = FALSE,
                   keep.pairScore = TRUE,
@@ -53,7 +50,7 @@ test_that("1 TTE endpoint - Gehan (no correction)", {
     iiScore <- do.call(rbind, iScore)
     iiScoreS <- iiScore[,.(n = n[1], favorable = sum(favorable), unfavorable = sum(unfavorable)),by = "endpoint"]
         
-    expect_equal(as.double(Gehan@Delta.netChance),iiScoreS[,cumsum(favorable-unfavorable)/n])
+    expect_equal(as.double(Gehan@Delta.netBenefit),iiScoreS[,cumsum(favorable-unfavorable)/n])
     expect_equal(as.double(Gehan@Delta.winRatio),iiScoreS[,cumsum(favorable)/cumsum(unfavorable)])
 })
 
@@ -62,19 +59,20 @@ test_that("1 TTE endpoint - Gehan (correction at the pair level)", {
     GehanC <- BuyseTest(group ~ tte(survie, censoring = event, threshold = 1) + cont(score),
                         data = df, 
                         method.tte = "Gehan", correction.uninf = TRUE)
-
+    ## getPairScore(GehanC)
+    
     expect_equal(as.double(GehanC@count.favorable), c(12,0))
     expect_equal(as.double(GehanC@count.unfavorable), c(2+2/3,0))
     expect_equal(as.double(GehanC@count.neutral), c(1 + 1/3,1 + 1/3))
     expect_equal(as.double(GehanC@count.uninf), c(0,0))
 
     iScore <- copy(getPairScore(GehanC, endpoint = 1, strata = 1))
-    expect_equal(iScore[, favorable + uninformative * sum(favorable)/sum(favorable + unfavorable + neutral)], iScore[["favorable.corrected"]])
-    expect_equal(iScore[, unfavorable + uninformative * sum(unfavorable)/sum(favorable + unfavorable + neutral)], iScore[["unfavorable.corrected"]])
-    expect_equal(iScore[, neutral + uninformative * sum(neutral)/sum(favorable + unfavorable + neutral)], iScore[["neutral.corrected"]])
+    expect_equal(iScore[, favorable + uninf * sum(favorable)/sum(favorable + unfavorable + neutral)], iScore[["favorableC"]])
+    expect_equal(iScore[, unfavorable + uninf * sum(unfavorable)/sum(favorable + unfavorable + neutral)], iScore[["unfavorableC"]])
+    expect_equal(iScore[, neutral + uninf * sum(neutral)/sum(favorable + unfavorable + neutral)], iScore[["neutralC"]])
     
-    expect_equal(as.double(GehanC@Delta.netChance)[1],iScore[,sum(favorable.corrected-unfavorable.corrected)/.N])
-    expect_equal(as.double(GehanC@Delta.winRatio)[1],iScore[,sum(favorable.corrected)/sum(unfavorable.corrected)])
+    expect_equal(as.double(GehanC@Delta.netBenefit)[1],iScore[,sum(favorableC-unfavorableC)/.N])
+    expect_equal(as.double(GehanC@Delta.winRatio)[1],iScore[,sum(favorableC)/sum(unfavorableC)])
 
 })
 
@@ -94,14 +92,14 @@ test_that("1 TTE endpoint - Gehan (correction IPCW)", {
     iScoreS <- iScore[,.(n = .N, favorable = sum(favorable), unfavorable = sum(unfavorable),
                          factor = .N/sum(favorable+unfavorable+neutral))]
 
-    expect_equal(as.double(GehanC@Delta.netChance[1]),iScoreS[,sum(favorable*factor-unfavorable*factor)/n])
+    expect_equal(as.double(GehanC@Delta.netBenefit[1]),iScoreS[,sum(favorable*factor-unfavorable*factor)/n])
     expect_equal(as.double(GehanC@Delta.winRatio[1]),iScoreS[,sum(favorable*factor)/sum(unfavorable*factor)])
 
     ## survival second
     GehanC2 <- BuyseTest(group ~  cont(score) + tte(survie, censoring = event, threshold = 1),
                          data = df, 
                          method.tte = "Gehan", correction.uninf = 2)
-
+    
     expect_equal(GehanC@count.favorable[1], GehanC2@count.favorable[2])
     expect_equal(GehanC@count.unfavorable[1], GehanC2@count.unfavorable[2])
     expect_equal(GehanC@count.neutral[1], GehanC@count.neutral[2])
@@ -111,12 +109,13 @@ test_that("1 TTE endpoint - Gehan (correction IPCW)", {
     iScoreS <- iScore[,.(n = .N, favorable = sum(favorable), unfavorable = sum(unfavorable),
                            factor = .N/sum(favorable+unfavorable+neutral))]
 
-    expect_equal(as.double(GehanC2@Delta.netChance[2]),iScoreS[,sum(favorable*factor-unfavorable*factor)/n])
+    expect_equal(as.double(GehanC2@Delta.netBenefit[2]),iScoreS[,sum(favorable*factor-unfavorable*factor)/n])
     expect_equal(as.double(GehanC2@Delta.winRatio[2]),iScoreS[,sum(favorable*factor)/cumsum(unfavorable*factor)])
 })
 
 ## ** Peron
 test_that("1 TTE endpoint - Peron (no correction)", {
+
     Peron <- BuyseTest(group ~ tte(survie, censoring = event, threshold = 1) + cont(score),
                        data = df, 
                        method.tte = "Peron", correction.uninf = FALSE)
@@ -130,7 +129,7 @@ test_that("1 TTE endpoint - Peron (no correction)", {
     iScore <- copy(getPairScore(Peron, endpoint = 1, strata = 1))
     iScoreS <- iScore[,.(n = .N, favorable = sum(favorable), unfavorable = sum(unfavorable))]
 
-    expect_equal(as.double(Peron@Delta.netChance[1]),iScoreS[,sum(favorable-unfavorable)/n])
+    expect_equal(as.double(Peron@Delta.netBenefit[1]),iScoreS[,sum(favorable-unfavorable)/n])
     expect_equal(as.double(Peron@Delta.winRatio[1]),iScoreS[,sum(favorable)/cumsum(unfavorable)])
 })
 
@@ -152,7 +151,7 @@ test_that("1 TTE endpoint - Peron (IPCW)", {
     iScoreS <- iScore[,.(n = .N, favorable = sum(favorable), unfavorable = sum(unfavorable), 
                          factor = .N/sum(favorable+unfavorable+neutral))]
 
-    expect_equal(as.double(PeronC@Delta.netChance[1]),iScoreS[,sum(favorable*factor-unfavorable*factor)/n])
+    expect_equal(as.double(PeronC@Delta.netBenefit[1]),iScoreS[,sum(favorable*factor-unfavorable*factor)/n])
     expect_equal(as.double(PeronC@Delta.winRatio[1]),iScoreS[,sum(favorable*factor)/cumsum(unfavorable*factor)])
 
     ## survival second
@@ -169,10 +168,56 @@ test_that("1 TTE endpoint - Peron (IPCW)", {
     iScoreS <- iScore[,.(n = .N, favorable = sum(favorable), unfavorable = sum(unfavorable), 
                          factor = .N/sum(favorable+unfavorable+neutral))]
 
-    expect_equal(as.double(PeronC2@Delta.netChance[1]),iScoreS[,sum(favorable*factor-unfavorable*factor)/n])
+    expect_equal(as.double(PeronC2@Delta.netBenefit[1]),iScoreS[,sum(favorable*factor-unfavorable*factor)/n])
     expect_equal(as.double(PeronC2@Delta.winRatio[1]),iScoreS[,sum(favorable*factor)/cumsum(unfavorable*factor)])
 })
 
+## * 2 endpoints
+## ** categorical variables
+
+## simulate data
+n <- 10
+set.seed(10)
+dt <- data.table(trt = c(rep(0,n/2),rep(1,n/2)),
+                 Y1 = 1,
+                 C = (1:n) %in% sample.int(n, n/2, replace = FALSE))
+dt[C==FALSE, Y1c := Y1]
+dt[,Y2 := as.numeric(NA)]
+dt[trt==0, Y2 := as.numeric(C)]
+dt[trt==1, Y2 := as.numeric(1-C)]
+
+## table(dt$trt,dt$Y1,dt$Y2)
+
+test_that("2 TTE endpoint - IPW induces bias when censoring is correlated with 2nd endpoint", {
+    BT.all <- BuyseTest(trt ~ cont(Y1, threshold = 1) + bin(Y2), data = dt,
+                        correction.uninf = 0, method.inference = "none")
+    expect_equal(as.double(BT.all@count.favorable), c(0,4))
+    expect_equal(as.double(BT.all@count.unfavorable), c(0,4))
+    expect_equal(as.double(BT.all@count.neutral), c(25,17))
+    expect_equal(as.double(BT.all@count.uninf), c(0,0))
+
+    BT.uninf <- BuyseTest(trt ~ cont(Y1c, threshold = 1) + bin(Y2), data = dt,
+                          correction.uninf = 0, method.inference = "none")
+    expect_equal(as.double(BT.uninf@count.favorable), c(0,4))
+    expect_equal(as.double(BT.uninf@count.unfavorable), c(0,4))
+    expect_equal(as.double(BT.uninf@count.neutral), c(4,17))
+    expect_equal(as.double(BT.uninf@count.uninf), c(21,0))
+
+    BT.ipw <- BuyseTest(trt ~ cont(Y1c, threshold = 1) + bin(Y2), data = dt,
+                        correction.uninf = 2, method.inference = "none")
+    expect_equal(as.double(BT.ipw@count.favorable), c(0,25))
+    expect_equal(as.double(BT.ipw@count.unfavorable), c(0,0))
+    expect_equal(as.double(BT.ipw@count.neutral), c(25,0))
+    expect_equal(as.double(BT.ipw@count.uninf), c(0,0))
+
+    BT.esp <- BuyseTest(trt ~ cont(Y1c, threshold = 1) + bin(Y2), data = dt,
+                        correction.uninf = 1, method.inference = "none", keep.pairScore = TRUE)
+    expect_equal(as.double(BT.esp@count.favorable), as.double(BT.all@count.favorable))
+    expect_equal(as.double(BT.esp@count.unfavorable), as.double(BT.all@count.unfavorable))
+    expect_equal(as.double(BT.esp@count.neutral), as.double(BT.all@count.neutral))
+    expect_equal(as.double(BT.esp@count.uninf), as.double(BT.all@count.uninf))
+
+})
 
 ##----------------------------------------------------------------------
 ### test-BuyseTest-correctionTTE.R ends here
